@@ -12,6 +12,7 @@ from . import utils
 import cement
 import copy
 import obj_tables
+import os
 import os.path
 import types  # noqa: F401
 
@@ -280,7 +281,7 @@ class VizSchemaController(cement.Controller):
     @cement.ex(hide=True)
     def _default(self):
         args = self.app.pargs
-        schema, _ = utils.init_schema(args.schema_file)
+        _, schema, _ = get_schema_models(args.schema_file)
         utils.viz_schema(schema, args.img_file)
         print('UML diagram saved to {}'.format(args.img_file))
 
@@ -304,7 +305,15 @@ class App(cement.App):
 
 def main():
     with App() as app:
-        app.run()
+        try:
+            app.run()
+        except SystemExit as exception:
+            raise exception
+        except Exception as exception:
+            if os.getenv('DEBUG', '0').lower() in ['1', 'true']:
+                raise exception
+            else:
+                raise SystemExit(str(exception))
 
 
 def get_schema_models(filename):
@@ -324,7 +333,7 @@ def get_schema_models(filename):
     if ext == '.py':
         schema = utils.get_schema(filename)
         schema_name = schema.__name__
+        models = list(utils.get_models(schema).values())
     else:
-        schema, schema_name = utils.init_schema(filename)
-    models = list(utils.get_models(schema).values())
+        schema, schema_name, models = utils.init_schema(filename)
     return (schema_name, schema, models)
